pub struct RequesterStudyAccessRequestRecord {
pub authority: String,
pub request_id: ObjectRef,
pub datastore_id: PublicUuid,
pub study: StudyRef,
pub intended_use: String,
pub contact: Option<String>,
pub affiliation: Option<String>,
pub status: StudyAccessRequestStatus,
pub submitted_at: DateTime<Utc>,
pub decided_at: Option<DateTime<Utc>>,
pub rejection_reason: Option<String>,
}Expand description
Browser-safe lifecycle metadata for a request owned by the current visitor.
This deliberately omits requester identity, custodian identity, and grant details. A request record is not evidence of Study access.
Fields
request_id: ObjectRefdatastore_id: PublicUuidstudy: StudyRefintended_use: Stringcontact: Option<String>affiliation: Option<String>status: StudyAccessRequestStatussubmitted_at: DateTime<Utc>decided_at: Option<DateTime<Utc>>rejection_reason: Option<String>Trait Implementations
Sourceimpl Clone for RequesterStudyAccessRequestRecord
impl Clone for RequesterStudyAccessRequestRecord
Sourcefn clone(&self) -> RequesterStudyAccessRequestRecord
fn clone(&self) -> RequesterStudyAccessRequestRecord
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for RequesterStudyAccessRequestRecord
impl<'de> Deserialize<'de> for RequesterStudyAccessRequestRecord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for RequesterStudyAccessRequestRecord
impl PartialEq for RequesterStudyAccessRequestRecord
Sourcefn eq(&self, other: &RequesterStudyAccessRequestRecord) -> bool
fn eq(&self, other: &RequesterStudyAccessRequestRecord) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for RequesterStudyAccessRequestRecord
impl StructuralPartialEq for RequesterStudyAccessRequestRecord