pub struct SafeAssetSummary {
pub asset_id: AssetRef,
pub study_id: StudyRef,
pub name: String,
pub description: Option<String>,
pub asset_type: AssetType,
pub date_created: Option<DateTime<Utc>>,
pub created_by: Option<String>,
}Expand description
Safe catalogue projection of an Asset.
Agent instructions are deliberately excluded because list operations do not authorize returning workflow instructions or other non-catalogue metadata.
Fields
asset_id: AssetRefstudy_id: StudyRefname: Stringdescription: Option<String>asset_type: AssetTypedate_created: Option<DateTime<Utc>>created_by: Option<String>Trait Implementations
Sourceimpl Clone for SafeAssetSummary
impl Clone for SafeAssetSummary
Sourcefn clone(&self) -> SafeAssetSummary
fn clone(&self) -> SafeAssetSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SafeAssetSummary
impl Debug for SafeAssetSummary
Sourceimpl<'de> Deserialize<'de> for SafeAssetSummary
impl<'de> Deserialize<'de> for SafeAssetSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SafeAssetSummary
impl PartialEq for SafeAssetSummary
Sourceimpl Serialize for SafeAssetSummary
impl Serialize for SafeAssetSummary
impl Eq for SafeAssetSummary
impl StructuralPartialEq for SafeAssetSummary