pub struct BrowserDataFileSearchResponse {
pub protocol_version: ProtocolVersion,
pub datastore_id: PublicUuid,
pub family: String,
pub predicates: PredicateSet<DataFilePredicate>,
pub datafiles: Vec<BrowserDataFileDiscoveryRecord>,
pub returned_count: u16,
pub requested_limit: u16,
pub ordering: BrowserSearchOrdering,
pub has_more: bool,
pub next_cursor: Option<String>,
pub empty_state: Option<BrowserDataFileSearchEmptyState>,
}Expand description
A browser-safe Datafile search page. Results reuse the existing Discovery record shape so descriptive size and storage-state facts may be returned while file bytes, digests, paths, and daemon state remain outside the Web contract.
Fields
protocol_version: ProtocolVersiondatastore_id: PublicUuidfamily: Stringpredicates: PredicateSet<DataFilePredicate>datafiles: Vec<BrowserDataFileDiscoveryRecord>returned_count: u16requested_limit: u16ordering: BrowserSearchOrderinghas_more: boolnext_cursor: Option<String>empty_state: Option<BrowserDataFileSearchEmptyState>Trait Implementations
Sourceimpl Clone for BrowserDataFileSearchResponse
impl Clone for BrowserDataFileSearchResponse
Sourcefn clone(&self) -> BrowserDataFileSearchResponse
fn clone(&self) -> BrowserDataFileSearchResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for BrowserDataFileSearchResponse
impl<'de> Deserialize<'de> for BrowserDataFileSearchResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for BrowserDataFileSearchResponse
impl PartialEq for BrowserDataFileSearchResponse
Sourcefn eq(&self, other: &BrowserDataFileSearchResponse) -> bool
fn eq(&self, other: &BrowserDataFileSearchResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for BrowserDataFileSearchResponse
impl StructuralPartialEq for BrowserDataFileSearchResponse