pub struct BrowserDictionaryDiscoveryResponse {
pub authority: String,
pub datastore_id: PublicUuid,
pub study: StudyRef,
pub resource: BrowserDictionaryDiscoveryDatasetRef,
pub domains: Vec<DomainSummary>,
pub variables: Vec<BrowserDictionaryVariableDiscoveryRecord>,
pub empty_state: Option<BrowserDictionaryDiscoveryEmptyState>,
pub content_derived_summaries: BrowserContentSummaryPolicy,
}Expand description
Browser dictionary discovery is a metadata-only variable projection.
It intentionally excludes dataset rows, datafile bytes, previews, Content-derived summaries, storage paths, raw SQL, credentials, diagnostics, and runtime handles.
Fields
datastore_id: PublicUuidstudy: StudyRefresource: BrowserDictionaryDiscoveryDatasetRefdomains: Vec<DomainSummary>variables: Vec<BrowserDictionaryVariableDiscoveryRecord>empty_state: Option<BrowserDictionaryDiscoveryEmptyState>content_derived_summaries: BrowserContentSummaryPolicyTrait Implementations
Sourceimpl Clone for BrowserDictionaryDiscoveryResponse
impl Clone for BrowserDictionaryDiscoveryResponse
Sourcefn clone(&self) -> BrowserDictionaryDiscoveryResponse
fn clone(&self) -> BrowserDictionaryDiscoveryResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for BrowserDictionaryDiscoveryResponse
impl<'de> Deserialize<'de> for BrowserDictionaryDiscoveryResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for BrowserDictionaryDiscoveryResponse
impl PartialEq for BrowserDictionaryDiscoveryResponse
Sourcefn eq(&self, other: &BrowserDictionaryDiscoveryResponse) -> bool
fn eq(&self, other: &BrowserDictionaryDiscoveryResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for BrowserDictionaryDiscoveryResponse
impl StructuralPartialEq for BrowserDictionaryDiscoveryResponse