pub struct BrowserResourceDiscoveryResponse {
pub authority: String,
pub datastore_id: PublicUuid,
pub study: StudyRef,
pub domains: Vec<DomainSummary>,
pub datasets: Vec<BrowserDatasetDiscoveryRecord>,
pub datafiles: Vec<BrowserDataFileDiscoveryRecord>,
pub datasets_empty_state: Option<BrowserResourceDiscoveryEmptyState>,
pub datafiles_empty_state: Option<BrowserResourceDiscoveryEmptyState>,
pub content_derived_summaries: BrowserContentSummaryPolicy,
}Expand description
Browser resource discovery is a broad Discovery metadata projection.
It intentionally excludes dataset rows, datafile bytes, previews, Content-derived summaries, storage paths, raw SQL, credentials, diagnostics, and runtime handles.
Fields
datastore_id: PublicUuidstudy: StudyRefdomains: Vec<DomainSummary>datasets: Vec<BrowserDatasetDiscoveryRecord>datafiles: Vec<BrowserDataFileDiscoveryRecord>datasets_empty_state: Option<BrowserResourceDiscoveryEmptyState>datafiles_empty_state: Option<BrowserResourceDiscoveryEmptyState>content_derived_summaries: BrowserContentSummaryPolicyTrait Implementations
Sourceimpl Clone for BrowserResourceDiscoveryResponse
impl Clone for BrowserResourceDiscoveryResponse
Sourcefn clone(&self) -> BrowserResourceDiscoveryResponse
fn clone(&self) -> BrowserResourceDiscoveryResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for BrowserResourceDiscoveryResponse
impl<'de> Deserialize<'de> for BrowserResourceDiscoveryResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for BrowserResourceDiscoveryResponse
impl PartialEq for BrowserResourceDiscoveryResponse
Sourcefn eq(&self, other: &BrowserResourceDiscoveryResponse) -> bool
fn eq(&self, other: &BrowserResourceDiscoveryResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for BrowserResourceDiscoveryResponse
impl StructuralPartialEq for BrowserResourceDiscoveryResponse