pub struct BrowserSemanticCatalogDiscoveryResponse {
pub authority: String,
pub datastore_id: PublicUuid,
pub study: StudyRef,
pub domains: Vec<DomainSummary>,
pub entities: Vec<BrowserEntityDiscoveryRecord>,
pub relations: Vec<BrowserEntityRelationDiscoveryRecord>,
pub provenance_summaries: Vec<BrowserProvenanceSummaryDiscoveryRecord>,
pub access_conditions: Vec<BrowserResourceAccessCondition>,
pub empty_state: Option<BrowserSemanticCatalogDiscoveryEmptyState>,
pub content_derived_summaries: BrowserContentSummaryPolicy,
}Expand description
Browser semantic catalog discovery is a metadata-only projection.
It intentionally excludes semantic instance values, protected content, Content-derived summaries, raw SQL, credentials, paths, runtime handles, and privileged workflow evidence.
Fields
datastore_id: PublicUuidstudy: StudyRefdomains: Vec<DomainSummary>entities: Vec<BrowserEntityDiscoveryRecord>relations: Vec<BrowserEntityRelationDiscoveryRecord>provenance_summaries: Vec<BrowserProvenanceSummaryDiscoveryRecord>access_conditions: Vec<BrowserResourceAccessCondition>empty_state: Option<BrowserSemanticCatalogDiscoveryEmptyState>content_derived_summaries: BrowserContentSummaryPolicyTrait Implementations
Sourceimpl Clone for BrowserSemanticCatalogDiscoveryResponse
impl Clone for BrowserSemanticCatalogDiscoveryResponse
Sourcefn clone(&self) -> BrowserSemanticCatalogDiscoveryResponse
fn clone(&self) -> BrowserSemanticCatalogDiscoveryResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for BrowserSemanticCatalogDiscoveryResponse
impl<'de> Deserialize<'de> for BrowserSemanticCatalogDiscoveryResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for BrowserSemanticCatalogDiscoveryResponse
impl PartialEq for BrowserSemanticCatalogDiscoveryResponse
Sourcefn eq(&self, other: &BrowserSemanticCatalogDiscoveryResponse) -> bool
fn eq(&self, other: &BrowserSemanticCatalogDiscoveryResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for BrowserSemanticCatalogDiscoveryResponse
impl StructuralPartialEq for BrowserSemanticCatalogDiscoveryResponse