pub struct BrowserStudyDiscoveryResponse {
pub authority: String,
pub datastore_id: PublicUuid,
pub studies: Vec<BrowserStudyDiscoveryRecord>,
pub empty_state: Option<BrowserStudyDiscoveryEmptyState>,
pub content_derived_summaries: BrowserContentSummaryPolicy,
}Expand description
Browser study discovery is a broad Discovery metadata projection.
It intentionally excludes Content-derived summaries, dataset rows, datafile bytes, access membership lists, custodian internals, storage paths, raw SQL, credentials, diagnostics, and runtime handles.
Fields
datastore_id: PublicUuidstudies: Vec<BrowserStudyDiscoveryRecord>empty_state: Option<BrowserStudyDiscoveryEmptyState>content_derived_summaries: BrowserContentSummaryPolicyTrait Implementations
Sourceimpl Clone for BrowserStudyDiscoveryResponse
impl Clone for BrowserStudyDiscoveryResponse
Sourcefn clone(&self) -> BrowserStudyDiscoveryResponse
fn clone(&self) -> BrowserStudyDiscoveryResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for BrowserStudyDiscoveryResponse
impl<'de> Deserialize<'de> for BrowserStudyDiscoveryResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for BrowserStudyDiscoveryResponse
impl PartialEq for BrowserStudyDiscoveryResponse
Sourcefn eq(&self, other: &BrowserStudyDiscoveryResponse) -> bool
fn eq(&self, other: &BrowserStudyDiscoveryResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for BrowserStudyDiscoveryResponse
impl StructuralPartialEq for BrowserStudyDiscoveryResponse