pub enum BrowserDictionaryDiscoveryDatasetRef {
Dataset {
dataset: DatasetRef,
},
}Expand description
The owning Dataset version returned by successful dictionary discovery.
This response type deliberately has no Datafile variant. The legacy request selector remains decodable only for the compatible HTTP transition.
Variants
Dataset
Fields

dataset: DatasetRefTrait Implementations
Sourceimpl Clone for BrowserDictionaryDiscoveryDatasetRef
impl Clone for BrowserDictionaryDiscoveryDatasetRef
Sourcefn clone(&self) -> BrowserDictionaryDiscoveryDatasetRef
fn clone(&self) -> BrowserDictionaryDiscoveryDatasetRef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for BrowserDictionaryDiscoveryDatasetRef
impl<'de> Deserialize<'de> for BrowserDictionaryDiscoveryDatasetRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for BrowserDictionaryDiscoveryDatasetRef
impl PartialEq for BrowserDictionaryDiscoveryDatasetRef
Sourcefn eq(&self, other: &BrowserDictionaryDiscoveryDatasetRef) -> bool
fn eq(&self, other: &BrowserDictionaryDiscoveryDatasetRef) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for BrowserDictionaryDiscoveryDatasetRef
impl StructuralPartialEq for BrowserDictionaryDiscoveryDatasetRef